@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0003';
+our $VERSION = '0.0004';
 
 use Moo;
 use strictures 2;
@@ -52,7 +52,7 @@ sub BUILD {
   $self->_sqlite->query(
     'create table if not exists '
     . $self->model
-    . ' (id integer primary key autoincrement, settings text not null)'
+    . ' (id integer primary key autoincrement, settings text not null, name text not null)'
   );
 }
 
@@ -60,6 +60,7 @@ sub BUILD {
 sub make_setting {
   my ($self, %args) = @_;
   my $id = delete $args{id};
+  my $name = delete $args{name};
   croak 'No columns given' unless keys %args;
   if ($id) {
     my $setting = $self->_sqlite->select(
@@ -79,6 +80,7 @@ sub make_setting {
       $self->model,
       {
         id       => $id,
+        name     => $name,
         settings => to_json(\%args),
       },
     )->last_insert_id;
@@ -90,6 +92,7 @@ sub make_setting {
 sub recall_setting {
   my ($self, %args) = @_;
   my $id = delete $args{id};
+  my $name = delete $args{name};
   croak 'No id given' unless $id;
   my $setting = $self->_sqlite->select(
     $self->model,
@@ -115,7 +118,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0003
+version 0.0004
 
 =head1 SYNOPSIS
 
@@ -123,11 +126,12 @@ version 0.0003
 
   my $synth = Synth::Config->new(model => 'Moog Matriarch');
 
-  my $result = $synth->make_setting(foo => 'bar', etc => '...');
+  my $id = $synth->make_setting(foo => 'bar', etc => '...');
 
-  $result = $synth->recall_setting(id => 42);
+  my $setting = $synth->recall_setting(id => $id);
+  # { foo => 'bar', etc => '...' }
 
-  #$result = $synth->render_setting(...); # TODO
+  #my $result = $synth->render_setting(...); # TODO
 
 =head1 DESCRIPTION
 
@@ -159,7 +163,7 @@ Default: C<synth-config.db>
 
 =head2 verbose
 
-  $verbose = $x->verbose;
+  $verbose = $synth->verbose;
 
 Show progress.
 
@@ -180,13 +184,15 @@ given B<model>.
 
   my $id = $synth->make_setting(%args);
 
-Save a setting with a db "update or insert" operation and return the
-record id.
+Save a named setting with a db "update or insert" operation and return
+the record id.
 
 Example:
 
-  group  parameter control bottom top   value unit is_default
-  filter cutoff    knob    20     20000 200   Hz   true
+  name: 'My Best Setting!'
+  settings:
+    group  parameter control bottom top   value unit is_default
+    filter cutoff    knob    20     20000 200   Hz   true
 
 =head2 recall_setting
 
